@@ -1,7 +1,7 @@
 package Term::Detect::Software;
 
 our $DATE = '2019-08-18'; # DATE
-our $VERSION = '0.220'; # VERSION
+our $VERSION = '0.221'; # VERSION
 
 use 5.010001;
 use strict;
@@ -233,7 +233,7 @@ Term::Detect::Software - Detect terminal (emulator) software and its capabilitie
 
 =head1 VERSION
 
-This document describes version 0.220 of Term::Detect::Software (from Perl distribution Term-Detect-Software), released on 2019-08-18.
+This document describes version 0.221 of Term::Detect::Software (from Perl distribution Term-Detect-Software), released on 2019-08-18.
 
 =head1 SYNOPSIS
 
@@ -281,14 +281,15 @@ Result:
 =item * emulator_engine => STR
 
 Possible values: C<konsole>, C<xterm>, C<gnome-terminal>, C<rxvt>, C<pterm>
-(PuTTY), C<xvt>, C<windows> (CMD.EXE), C<cygwin>, or empty string (if not
-detected running under terminal).
+(PuTTY), C<xvt>, C<windows> (CMD.EXE), C<cygwin>, C<st> (suckless.org's terminal
+emulator), or empty string (if not detected running under terminal).
 
 =item * emulator_software => STR
 
 Either: C<xfce4-terminal>, C<guake>, C<gnome-terminal>, C<mlterm>,
-C<lxterminal>, C<rxvt>, C<mrxvt>, C<putty>, C<xvt>, C<windows> (CMD.EXE), or
-empty string (if not detected running under terminal).
+C<lxterminal>, C<rxvt>, C<mrxvt>, C<putty>, C<xvt>, C<windows> (CMD.EXE), C<st>
+(suckless.org's terminal emulator), or empty string (if not detected running
+under terminal).
 
 =item * color_depth => INT
 
